@@ -24,12 +24,11 @@ import os
 import sys
 
 if __debug__:
-    from sidetrack import set_debug, log, logr
+    from sidetrack import log
 
 import handprint
 from handprint.credentials.microsoft_auth import MicrosoftCredentials
 from handprint.exceptions import *
-from handprint.network import net
 from handprint.services.base import TextRecognition, TRResult, Box
 
 
@@ -150,7 +149,7 @@ class MicrosoftTR(TextRecognition):
         # processing, then wait & poll until the text is ready to be retrieved.
 
         if __debug__: log(f'contacting Microsoft for {relative(path)}')
-        response = self._net('post', url, headers, image)
+        response = self._api('post', url, headers, image)
         if isinstance(response, tuple):
             return response             # If get back a tuple, it's an error.
 
@@ -167,7 +166,7 @@ class MicrosoftTR(TextRecognition):
             # Have never seen results returned in 1 s, and meanwhile, polling
             # still counts against our rate limit.  Wait 2 s to reduce calls.
             wait(2)
-            response = self._net('get', poll_url, headers = headers, polling = True)
+            response = self._api('get', poll_url, headers = headers, polling = True)
             if isinstance(response, tuple):
                 return response         # If get back a tuple, it's an error.
 
@@ -202,7 +201,8 @@ class MicrosoftTR(TextRecognition):
         return analysis
 
 
-    def _net(self, get_or_post, url, headers, data = None, polling = False):
+    def _api(self, get_or_post, url, headers, data = None, polling = False):
+        from handprint.network import net
         response, error = net(get_or_post, url, headers = headers,
                               data = data, polling = polling)
         if isinstance(error, NetworkFailure):
@@ -217,7 +217,7 @@ class MicrosoftTR(TextRecognition):
                 sleep_time = int(response.headers['Retry-After'])
             if __debug__: log(f'sleeping for {sleep_time} s and retrying')
             wait(sleep_time)
-            return self._net(get_or_post, url, headers, data, polling) # Recurse
+            return self._api(get_or_post, url, headers, data, polling) # Recurse
         elif error:
             if isinstance(error, ServiceFailure):
                 # If it was an error generated by the Microsoft service, there
